.. Tqueues documentation master file, created by
   sphinx-quickstart on Mon May  2 13:40:00 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Tqueues's documentation!
===================================

.. include:: Readme.rst

.. toctree::
   API
   :maxdepth: 2


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

